-- BandSquad Database
-- Author : Daniel Sirait <dns@cpan.org>
--
-- Copyright 2007 BandSquad Inc.
-- http://dev.bandsquad.com/
--
-- PgSQL, Oracle, MySQL compatible
--


CREATE TABLE bs_admins (
	id				bigint unsigned auto_increment not null,
	sid				varchar(40) default null,
	name			varchar(16) not null,
	email			varchar(30) not null,
	pswd			varchar(16) not null,
	primary key (id)
);

CREATE TABLE bs_unver_users (
	email			varchar(30) not null,
	username		varchar(16) not null,
	pswd			varchar(16) not null,
	ver_code		varchar(40) not null,
	primary key (email)
);

CREATE TABLE bs_users (
	uid				bigint unsigned auto_increment not null,
	sid				varchar(40) default null,
	email			varchar(32) not null,
	username		varchar(16) not null,
	is_active		int not null,						-- 0 / 1
	reg_date		varchar(10) not null,			-- 17;08;1945
	gender			varchar(6) not null,				-- male / female
	www				varchar(128) default null,
	pswd			varchar(16) not null,
	ggenre			varchar(16) not null,			-- genre (general)
	ogenre			varchar(32) default null,		-- other genre
	instrument		varchar(16) default null,
	bands			varchar(128) default null,
	additional_bands	varchar(128) default null,
	about			varchar(2048) default null,
	pics			varchar(512) default null,		-- http://domain.com/path/file.jpg#S#     |     $uid-$picname-int rand 99999;   max 5 pics, max 200kb
	msg				varchar(100000) default null,	-- user INBOX, max: 30 msg ..  eg: title[SEP]msg[SEP]date[!MSG!]
	news			varchar(16384) default null,		-- title here[!SPR!]date here[!SPR!]comment here[!MSG!] ...   max: 25
	mp3_pub			varchar(16384) default null,		-- http://domain.com/path/file.mp3#S#   max: 100
	mp3_priv		varchar(16384) default null,		-- http://domain.com/path/file.mp3#S#
	vid_pub			varchar(16384) default null,		-- http://domain.com/path/file.swf#S#
	vid_priv		varchar(16384) default null,		-- http://domain.com/path/file.swf#S#
	bookmark_users	varchar(1024) default null,		-- max 100 user
	bookmark_bands	varchar(4050) default null,		-- max 100 band
	primary key (uid),
	unique (email)
);



-- 123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890
CREATE TABLE bs_bands (
	bandname		varchar(40) not null,		-- max: 40 char, can not contain #, =, +
	is_active		int not null,					-- 1: active, 0: inactive , DEFAULT: 1
	reg_date		varchar(10) not null,
	members			varchar(512) default null,	-- founder_uid;uid;uid;	-> eg: 425;684;22;
	additional		varchar(512) default null,	-- additional members	-> eg: 1525,4568
	former			varchar(1024) default null,	-- former members		-> eg: 26;842
	albums			varchar(1024) default null,	-- disabled
	ggenre			varchar(16) not null,
	ogenre			varchar(64) not null,		-- mixed genres
	label			varchar(64) not null,		-- record label
	location		varchar(32) default null,	-- band location
	c_location		varchar(20) not null,		-- country location
	about			varchar(2048) default null,	-- max 2 KB
	linked_bands	varchar(256) default null,	-- as i lay dying;korn;lost prophets;	->  require approval
	pics			varchar(512) default null,	-- $bandname-$picname-int rand 99999; max 5 pics,    max 200kb
	reputation		varchar(12) not null,		-- ADMIN/MOD ACCESS ! eg: obscure, novice, professional, regional, continental, worldwide, etc..
	rating			int unsigned not null,			-- 0 - 100 ! ADMIN/MOD ACCESS
	activity		int unsigned not null,			-- 0 - 100 ! BS BOT ACCESS (AUTO RATING SYSTEM)
	testimonial		varchar(16384) not null,		-- title here[!SPR!]date here[!SPR!]posted by[!SPR!]comment here[!MSG!] ...   max: 25
	mp3_pub			varchar(16384) default null,	-- http://domain.com/path/file.mp3#S#
	mp3_priv		varchar(16384) default null,	-- http://domain.com/path/file.mp3#S#
	vid_pub			varchar(16384) default null,	-- http://domain.com/path/file.mp3#S#
	vid_priv		varchar(16384) default null,	-- http://domain.com/path/file.mp3#S#
	primary key (bandname)
);

CREATE TABLE bs_labels (
	labelname		varchar(30) not null,		-- record label
	location		varchar(32)	not null,
	type			varchar(16) not null,		-- type of label: idie, major label, local label, regional label
	logo			varchar(1024) default null,	-- max 1 kb, GET method for external links
	bands			varchar(2048) default null,
	primary key (labelname)
);

-- $bandname . ' - ' . $bandsong
CREATE TABLE bs_bandfiles (
	band_owner		varchar(30) not null,
	filename		varchar(64) not null,
	lyrick			varchar(4096) default null,
	primary key (band_owner)
);


-- &username($uid) . ' - ' . $mp3filename.mp3
CREATE TABLE bs_userfiles (
	user_owner		bigint unsigned not null,		-- uid
	filename		varchar(64) not null,
	primary key (user_owner)
);

CREATE TABLE bs_referer (
	referer_url		varchar(32) default null,
	primary key (referer_url)
);


INSERT INTO `bs_users` (`username`, `www`, `email`, `pswd`)
	VALUES ('sysadmin', 'http://dev.bandsquad.com/', 'sysadmin@bandsquad.com', 'sysadmin');


INSERT INTO `bs_bands` (`bandname`, `is_active`, `members`, `additional`, `former`, `albums`, `genre`, `label`, `location`, `c_location`, `about`, `linked_bands`, `reputation`, `rating`, `activity`)
	VALUES ('Fresh Blood', 1, '1;', '', '', '', 'Metalcore', 'BandSquad Records', 'Jakarta', 'Indonesia', '', 'Regex;As I Lay Dying;Dark Fluid;', 'Novice', 70, 84
);
