<?php

/**
* Usage: pagination class
* @package WebIntegrator_main
*/

/**
* class SimplePageMaker holds data about simple linear display of item arrays  
*
* Usage:
*
*	<code>
*	$pm = new SimplePageMaker(110,$_REQUEST[page]);
*	
*	$pm->set('file','someother.php'); // sets other file
*	$pm->set('delimiter',' <span style="font-size: 
*40px; vertical-align: middle;">&middot;</span> '); // sets delimiter
*	$pm->set('link_active','width: 36px; vertical-align: middle; 
*border: 2px outset #FFCC99; padding:4px; font-weight: bold; 
*font-family: Arial; color: red;'); // sets active span style
*	$pm->set('link_inactive','color: blue; padding:4px; 
*text-decoration: none; font-weight: bold; font-family: 
*Arial;'); // sets inactive link style
*	$pm->set('requesttail','&a=21&c=51&shit=toomuch'); // sets link tail
*	$pm->set('items',10); // set limit of items between prev and next
*	$pm->set('itemsperpage',100); // set number of items per page
*	$pm->set('vertical_delimiter','<br>'); // set vertical delimiter
*	$pm->set('show_rewinds',true); 
* // sets policy if rewind back and fast forward are shown
*	$pm->make();
*
*	echo '<a href="'._ME.'">reset</a><br>';
*	echo '<center>'.$pm->show().'</center><br>';
*	echo '<pre>';
*	print_r($pm->get_range());
*	</code>
*
* @author  Oleksandr Missa <alecksmart8@list.ru>
* @copyright Oleksandr Missa (C)  DDT Studio 2000-2003 (C)
* @access  public
* @package WebIntegrator_main
*/

class SimplePageMaker extends object {
	/** */
	var $page ;
	/** */
	var $all ;
	/** */
	var $holder = array();
	/** */
	var $pageholder = array() ;
	/** */
	var $items = 10 ;
	/** */
	var $link_active = 'color: red;' ;
	/** */
	var $link_inactive = '' ;
	/** */
	var $output = '' ;
	/** */
	var $nextpage = false ;
	/** */
	var $prevpage = false ;
	/** */
	var $chunked ;
	/** */
	var $currentpage = false ;
	/** */
	var $delimiter = ' :: ' ;
	/** */
	var $vertical_delimiter = '<br>' ;
	/** */
	var $file=_ME ;
	/** */
	var $requestname = 'page' ;
	/** */
	var $requesttail = '' ;
	/** */
	var $shift_prev = '&lt;&lt;' ;
	/** */
	var $shift_next = '&gt;&gt;' ;
	/** */
	var $itemsperpage = 10 ;
	/** */
	var $show_rewinds = false ;
	/** */
	var $rewind_first = '&lt;&lt;&lt;' ;
	/** */
	var $rewind_last = '&gt;&gt;&gt;' ;

	function SimplePageMaker($all,$page) {
		if(!function_exists('array_chunk')||!function_exists('array_key_exists')) {
			trigger_error(sprintf('SimplePageMaker::constructor() - sorry, your php version is too old and I am too lazy to paginate :)'),E_USER_ERROR) ;
		} // if
		$this->all = $all ;
		$this->page = $page ? $page : 1 ;
	} // end_f-n
	function calculate() {
		if(!$this->all) {
			return ;
		} // if
		for($i=0; $i<$this->all; $i++) {
			$this->holder[$i+1] = $i ;
		} // for
		$this->chunked = array_chunk($this->holder,$this->itemsperpage,true) ;
		$this->pages=array_keys($this->chunked);
		$this->chunks = array_chunk($this->pages,$this->items,true);
		for($i=0; $i<count($this->chunks); $i++) {
			if(array_key_exists($this->page-1,$this->chunks[$i])) {
				$this->currentpage = $i ;
				break;
			} // if
		} // for
		if(isset($this->chunks[$this->currentpage-1])) {
			$c = array_keys($this->chunks[$this->currentpage-1]);
			$this->prevpage = $c[count($c)-1];
		} // if
		if(isset($this->chunks[$this->currentpage+1])) {
			$c = array_keys($this->chunks[$this->currentpage+1]);
			$this->nextpage = $c[0];
		} // if
	} // end_f-n
	function make() {
		$this->calculate();
		if(!$this->all) {
			return ;
		} // if
		if(!array_key_exists($this->page-1,$this->pages)) {
			trigger_error(sprintf('SimplePageMaker::make() - out of bounds in page %s',$this->page),E_USER_ERROR) ;
		} // if
		if($this->show_rewinds && count($this->pages)>$this->items) {
			$this->output .= 
				'<a href="'.$this->file.'?'.$this->requestname.'=1'. $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->rewind_first . '</a>' . $this->delimiter ;
			if($this->prevpage) {
				$this->output .= 
					'<a href="'.$this->file.'?'.$this->requestname.'='.($this->prevpage+1). $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_prev . '</a>' . $this->delimiter ;
			} // if	
			else {
				$this->output .= 
				'<a href="'.$this->file.'?'.$this->requestname.'=1'. $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_prev . '</a>' . $this->delimiter ;
			} // else
		} // if
		else {
			if($this->prevpage) {
				$this->output .= 
					'<a href="'.$this->file.'?'.$this->requestname.'='.($this->prevpage+1). $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_prev . '</a>' . $this->delimiter ;
			} // if	
		} // else
		foreach($this->chunks[$this->currentpage] as $k=>$v) {
			$delimiter = isset($this->chunks[$this->currentpage][$k+1]) || $this->nextpage ? $this->delimiter : '' ;
			if($this->page == $k+1) {
				$this->output .= 
					'<span style="'. $this->link_active . '">' . ($k+1) . 
					'</span>' . $delimiter ;
				continue ;
			} // if
			$this->output .= 
					'<a href="'.$this->file.'?'.$this->requestname.'='.($k+1). $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . ($k+1) . 
					'</a>' . $delimiter ;
		} // foreach
		if($this->show_rewinds && count($this->pages)>$this->items) {
			$c = array_keys($this->pages);
			$last = $this->pages[$c[count($c)-1]] + 1 ;
			if($this->nextpage) {
				$this->output .= 
					'<a href="'.$this->file.'?'.$this->requestname.'='.($this->nextpage+1). $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_next . '</a>'  ;
			} // if
			else {
				$this->output .=  $this->delimiter
					. '<a href="'.$this->file.'?'.$this->requestname.'='.$last. $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_next . '</a>'  ;
			} // else
			$this->output .= $this->delimiter 
					. '<a href="'.$this->file.'?'.$this->requestname.'='.$last. $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->rewind_last . '</a>'  ;
		} // if
		else {
			if($this->nextpage) {
				$this->output .= 
					'<a href="'.$this->file.'?'.$this->requestname.'='.($this->nextpage+1). $this->requesttail. 
					'" style="'. $this->link_inactive . '">' . $this->shift_next . '</a>'  ;
			} // if
		} // else
	} // end_f-n
	function get_range() {
		return array_slice($this->holder,($this->page-1)*$this->itemsperpage,$this->itemsperpage);
	} // end_f-n
	function show() {
		return $this->output ;
	} // end_f-n
	function show_vertical() {
		return str_replace($this->delimiter,$this->vertical_delimiter,$this->output) ;
	} // end_f-n
} // end_class	 


	function &paginate($count,$name,$props=array()) {
		$pm = &new SimplePageMaker($count,$_REQUEST[$name]);
		$pm->set('requestname',$name); 
		$pm->set('delimiter',' <span>&middot;</span> '); 
		$pm->set('link_active','color: red; font-weight: bold;'); 
		$pm->set('link_inactive','color: blue; text-decoration: none; font-weight: bold;'); 
		$pm->set('items',10); 
		$pm->set('itemsperpage',16); 
		if(!empty($props)) {
			foreach($props as $k=>$v) {
				$pm->set($k,$v);
			} // foreach
		} // if
		$pm->make();
		return $pm ;
	} // f-n


?>